package Firewall::Config::Element::Schedule::Role;

#------------------------------------------------------------------------------
# 加载扩展模块
#------------------------------------------------------------------------------
use Moose::Role;

#------------------------------------------------------------------------------
# 加载 Firewall::Config::Element::Role 角色
#------------------------------------------------------------------------------
with 'Firewall::Config::Element::Role';

#------------------------------------------------------------------------------
# Firewall::Config::Element::Schedule::Role 通用属性
#------------------------------------------------------------------------------
has schName => ( is => 'ro', isa => 'Str', required => 1, );

has schType => ( is => 'ro', isa => 'Str', required => 1, );

#------------------------------------------------------------------------------
# 引用该模块的子类必须实现的方法
#------------------------------------------------------------------------------
requires 'isExpired';

1;
